/* config.h.  Generated by configure.  */
#define PACKAGE_NAME "scponly"
#define PACKAGE_VERSION "4.8"
#define PACKAGE_BUGREPORT "joe@sublimation.org"

/* Features */
/* #undef UNIX_COMPAT */
/* #undef IRIX_COMPAT */
#define WINSCP_COMPAT 1
#define GFTP_COMPAT 1
/* #undef SVN_COMPAT */
/* #undef RSYNC_COMPAT */
/* #undef QUOTA_COMPAT */
/* #undef UNISON_COMPAT */
/* #undef PASSWD_COMPAT */
#define ENABLE_SCP2 1
#define ENABLE_SFTP 1
/* #undef SVNSERV_COMPAT */
#define ENABLE_WILDCARDS 1
#define RESTRICTIVE_FILENAMES 1
#define CHROOTED_NAME "scponlyc"
#define CHROOT_CHECKDIR 1
#define HAVE_WORDEXP 1
#define HAVE_GLOB 1
#define HAVE_GETOPT 1
#define HAVE_GETOPT_H 1
/* #undef HAVE_OPTRESET */

/* #undef ENABLE_DEFAULT_CHDIR */
/* cd to this directory after authentication */
#ifdef ENABLE_DEFAULT_CHDIR
/* #undef DEFAULT_CHDIR */
#endif

/* Binaries launched in sftp compat mode */
#ifdef ENABLE_SFTP
#define PROG_SFTP_SERVER "/usr/lib/ssh/sftp-server"
#endif

/* Binaries launched by vanilla- and win-SCP modes */
#ifdef ENABLE_SCP2
#define PROG_LS "/usr/bin/ls"
#define PROG_SCP "/usr/bin/scp"
#define PROG_RM "/usr/bin/rm"
#define PROG_LN "/usr/bin/ln"
#define PROG_MV "/usr/bin/mv"
#define PROG_CHMOD "/usr/bin/chmod"
#define PROG_CHOWN "/usr/bin/chown"
#define PROG_CHGRP "/usr/bin/chgrp"
#define PROG_MKDIR "/usr/bin/mkdir"
#define PROG_RMDIR "/usr/bin/rmdir"
#define PROG_CD "cd"
#endif /*ENABLE_SCP2*/

/* sftp logging compatibility mode */
/* #undef SFTP_LOGGING */

#ifdef SFTP_LOGGING
#define USE_SAFE_ENVIRONMENT
#endif

/* Binaries launched in WinSCP compatibility mode */
#ifdef WINSCP_COMPAT
#define PROG_PWD "/usr/bin/pwd"
#define PROG_GROUPS "/usr/bin/groups"
#define PROG_ID "/usr/bin/id"
#define PROG_ECHO "/usr/bin/echo"
#endif

/* Rsync compatability mode */
#ifdef RSYNC_COMPAT
/* #undef PROG_RSYNC */
#endif

/* Unison compatability mode */
#ifdef UNISON_COMPAT
/* #undef PROG_UNISON */
#ifndef USE_SAFE_ENVIRONMENT
#define USE_SAFE_ENVIRONMENT
#endif
#endif

/* subversion cli compatibility */
#ifdef SVN_COMPAT
/* #undef PROG_SVN */
#endif

/* subversion svnserv compatibility */
#ifdef SVNSERV_COMPAT
/* #undef PROG_SVNSERV */
#endif

/* passwd compatibility */
#ifdef PASSWD_COMPAT
/* #undef PROG_PASSWD */
#endif

/* quota compatibility */
#ifdef QUOTA_COMPAT
/* #undef PROG_QUOTA */
#endif

